@@ -91,7 +91,6 @@ class MqttJwtToken:
             timer.start()
 
     def retrieving(self):
-        # todo: 1. 生产环境refresh失败(卡住不动), 在生产环境上把失效时间改短测试
 
         token = self.get_token()
         if token is not None:
@@ -187,8 +186,6 @@ class JwtMqttClient(threading.Thread, metaclass=ABCMeta):
         client.on_publish = self.on_publish if 'on_publish' not in self.callbacks else self.callbacks['on_publish']
 
         client.connect(host=self.token['host'], port=self.token['port'])
-        if self.__class__.__name__ == 'JwtMqttClientSub':
-            client.loop_start()
 
         return client
 
@@ -216,9 +213,8 @@ class JwtMqttClient(threading.Thread, metaclass=ABCMeta):
         print(f'Published {mid}')
 
     def end(self):
-        if self.__class__.__name__ == 'JwtMqttClientSub':
-            self.client.loop_stop()
         self.client.disconnect()
+        self.client.loop_stop()
 
 
 class JwtMqttClientSub(JwtMqttClient):
@@ -231,6 +227,7 @@ class JwtMqttClientSub(JwtMqttClient):
         # multiple topics: [('topic1', 0), ('topic2', 0)]
         result, mid = self.client.subscribe(self.topic)
         self.no_response_sub.append(mid)
+        self.client.loop_forever()
 
 
 class JwtMqttClientPub(JwtMqttClient):
